package main

import (
	"context"
	"encoding/json"
	"gitea.cdlsxd.cn/sdk/plugin/instance"
	"gitea.cdlsxd.cn/sdk/plugin/manage"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"log"
)

var zltxConf = &manage.Config{
	Cmd:         "pkg/mac/zltx_v1.so",
	Tag:         "zltx_v1",
	Version:     1,
	CookieKey:   "zltx_v1",
	CookieValue: "zltx_v1",
}

func config() []byte {
	type Config struct {
		AppId      string `json:"app_id"`
		AppKey     string `json:"app_key"`
		BaseUri    string `json:"base_uri"`
		NotifyUrl  string `json:"notify_url"`
		MerchantId int64  `json:"merchant_id"`
	}
	c := &Config{
		AppId:      "1",
		AppKey:     "1e2bf7a04b8b1e6be5dc78d04e8639c9",
		BaseUri:    "http://test.openapi.1688sup.cn",
		NotifyUrl:  "https://gateway.dev.cdlsxd.cn/yxh5api/v1/order/direct/notify",
		MerchantId: 25537,
	}
	marshal, _ := json.Marshal(c)
	return marshal
}

// main 这只是一个演示
func zltx() {
	err := manage.Add(zltxConf)
	if err != nil {
		log.Fatalln(err)
	}
	defer manage.Close()
	orderRequest := &proto.OrderRequest{
		Config: config(),
		Order: &proto.OrderRequest_Order{
			OrderNo:  "test_main_zltx_6",
			Account:  "18666666666",
			Quantity: 1,
			Extra:    nil,
		},
		Product: &proto.OrderRequest_Product{
			ProductNo: "106",
			Extra:     []byte(`{}`),
		},
	}
	queryRequest := &proto.QueryRequest{
		Config: config(),
		Order: &proto.QueryRequest_Order{
			OrderNo: "test_main_zltx_6",
		},
	}
	res, err := instance.Order(context.Background(), zltxConf.Tag, orderRequest)
	if err != nil {
		log.Fatalln(err)
	}
	log.Printf("Order res:%+v", res)

	resQuery, err := instance.Query(context.Background(), zltxConf.Tag, queryRequest)
	if err != nil {
		log.Fatalln(err)
	}
	log.Printf("Query res:%+v", resQuery)
}

func zltxQuery() {
	err := manage.Add(zltxConf)
	if err != nil {
		log.Fatalln(err)
	}
	defer manage.Close()
	queryRequest := &proto.QueryRequest{
		Config: config(),
		Order: &proto.QueryRequest_Order{
			OrderNo: "test_plugin_zltx_v1_direct_2",
		},
	}
	resQuery, err := instance.Query(context.Background(), zltxConf.Tag, queryRequest)
	if err != nil {
		log.Fatalln(err)
	}
	log.Printf("Query res:%+v", resQuery)
}
