package internal

import (
	"context"
	"fmt"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"plugins/wechat_redpack/internal/vo"
	"strings"
)

// 插件通信信息,若不对应则会报错panic
const (
	Tag         = "wechat_redpack"
	Version     = 1
	CookieKey   = "wechat_redpack"
	CookieValue = "wechat_redpack"
)

// WeChatRedPackService @link https://pay.weixin.qq.com/docs/merchant/apis/batch-transfer-to-balance/transfer-batch/initiate-batch-transfer.html
type WeChatRedPackService struct{}

func (p *WeChatRedPackService) Order(ctx context.Context, request *proto.OrderRequest) (*proto.OrderResponse, error) {
	config, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}

	req, err := orderReq(request.GetOrder(), request.GetProduct())
	if err != nil {
		return nil, proto.ErrorParamFail(err.Error())
	}

	svc, err := transferBatchApiService(ctx, config)
	if err != nil {
		return nil, proto.ErrorRequestFail(err.Error())
	}

	resp, result, err := svc.InitiateBatchTransfer(ctx, req)
	if err != nil {
		return nil, proto.ErrorRequestFail("微信返回错误:" + p.err(ctx, err).Error())
	}
	if result.Response.StatusCode != vo.CodeSuccess.Value() {
		return nil, proto.ErrorRequestFail(fmt.Sprintf("微信返回错误StatusCode[%d]Status[%s]", result.Response.StatusCode, result.Response.Status))
	}
	return orderResp(request.GetOrder(), *resp.BatchId), nil
}

func (p *WeChatRedPackService) Query(ctx context.Context, request *proto.QueryRequest) (*proto.QueryResponse, error) {
	config, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}

	req, err := queryReq(request.GetOrder())
	if err != nil {
		return nil, proto.ErrorParamFail(err.Error())
	}

	svc, err := transferDetailApiService(ctx, config)
	if err != nil {
		return nil, proto.ErrorRequestFail(err.Error())
	}

	resp, result, err := svc.GetTransferDetailByOutNo(ctx, *req)
	if err != nil {
		return nil, proto.ErrorRequestFail("微信返回错误:" + p.err(ctx, err).Error())
	}
	if result.Response.StatusCode != vo.CodeSuccess.Value() {
		return nil, proto.ErrorRequestFail(fmt.Sprintf("微信返回错误StatusCode[%d]Status[%s]", result.Response.StatusCode, result.Response.Status))
	}
	return queryResp(request, resp), nil
}

func (p *WeChatRedPackService) Notify(_ context.Context, _ *proto.NotifyRequest) (*proto.NotifyResponse, error) {
	return notifyResp(), nil
}

func (p *WeChatRedPackService) err(_ context.Context, err error) error {
	errStr := err.Error()
	startIndex := strings.Index(errStr, "Message: ")
	if startIndex == -1 {
		return err
	}
	endIndex := strings.Index(errStr[startIndex:], "\n")
	if endIndex == -1 {
		return err
	}
	return fmt.Errorf(errStr[startIndex+len("Message: ") : startIndex+endIndex])
}
