package internal

import (
	"context"
	"encoding/json"
	"fmt"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"github.com/stretchr/testify/assert"
	"net/http"
	"testing"
)

var zltx = &ZLTXV2Service{}

func config() []byte {
	c := &Config{
		AppId:     "25891",
		AppKey:    "83cc38e09560417ad7ea0feaaae9d171",
		BaseUri:   "http://211.137.105.198:17100",
		NotifyUrl: "https://gateway.dev.cdlsxd.cn/yxh5api/v1/order/direct/notify",
	}
	//{"app_id":"25891","app_key":"83cc38e09560417ad7ea0feaaae9d171","merchant_id":25891}
	marshal, _ := json.Marshal(c)
	return marshal
}

func TestConfig(t *testing.T) {
	t.Run("TestConfig", func(t *testing.T) {
		c := config()
		fmt.Printf("%s\n", string(c))
		assert.NotEmpty(t, c)
	})
}

func TestOrder(t *testing.T) {
	request := &proto.OrderRequest{
		Config: config(),
		Order: &proto.OrderRequest_Order{
			OrderNo:  "test_zltx_v2_7",
			Account:  "18666173766",
			Quantity: 1,
			Extra:    nil,
		},
		Product: &proto.OrderRequest_Product{
			ProductNo: "106",
			Extra:     []byte(`{}`),
		},
	}

	t.Run("TestOrder", func(t *testing.T) {
		got, err := zltx.Order(context.Background(), request)
		if err != nil {
			t.Errorf("Order() error = %v", err)
			return
		}
		fmt.Printf("%+v\n", got)
		assert.Equal(t, int(proto.Status_ING), int(got.Result.Status))
	})
}

func TestQuery(t *testing.T) {
	request := &proto.QueryRequest{
		Config: config(),
		Order: &proto.QueryRequest_Order{
			OrderNo: "test_zltx_v2_7",
			TradeNo: "", // 731095414466813953
			Account: "",
			Extra:   nil,
		},
	}
	t.Run("TestQuery", func(t *testing.T) {
		got, err := zltx.Query(context.Background(), request)
		if err != nil {
			t.Errorf("Query() error = %v", err)
			return
		}
		fmt.Printf("%+v\n", got)
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}

func TestNotify(t *testing.T) {
	bodyBytes := []byte(`{"tradeStatus":"SUCCESS","orderNo":"C2169720720874659840","tradeStateDesc":"成功","cards":[{"no":"RpHWw3cEhiRW764pFoKVHKRypwZg8Txf0YAW8dE+F7lsrkoUKaAlkYL549lRWp+Q","pwd":"","url":"hei8pdKAWO7aiFHPmtZWg1iTupwk3oXV8QH7IVBtUpoPhFt6wksIiN034wbbe9sOo8Wpl7iOXUVSd50mJdwDknUi8BpitNpODfjjiTt7vTk=","deadline":"2025-09-30 00:00:00","cardType":3}],"mchId":25891,"outTradeNo":"202504031355308910010048","rechargeAccount":"","attach":"","unitPrice":27}`)
	headerBytes := []byte(`{"Accept-Encoding":["gzip"],"Authorization":["a4decf2803323a023d187578f85f4d21"],"Connection":["close"],"Content-Length":["442"],"Content-Type":["application/json"],"Lsxd-Api-Proxy":["v2"],"Lsxd-From-System":["card"],"Lsxd-Signature":["bc0eb734101796c5bd1fe72472b406a4"],"Lsxd-Timestamp":["1743659731"],"User-Agent":["Go-http-client/1.1"],"X-Envoy-Attempt-Count":["1"],"X-Forwarded-Client-Cert":["By=spiffe://cluster.local/ns/gopro/sa/default;Hash=4798784d2ecd4218a4b71b4d08737f9714e2dbd508446d916b2999fd22d5811c;Subject=\"\";URI=spiffe://cluster.local/ns/card/sa/default"],"X-Forwarded-For":["112.124.3.46"],"X-Forwarded-Proto":["http"],"X-Real-Ip":["112.124.3.46"],"X-Remoteaddr":["172.18.0.1"],"X-Request-Id":["eab52927-95c8-4e64-9f5c-8a5f2aa339c1"]}`)

	in := &proto.NotifyRequest{
		Config:  config(),
		Queries: nil,
		Headers: headerBytes,
		Body:    bodyBytes,
	}

	t.Run("TestNotify", func(t *testing.T) {
		got, err := zltx.Notify(context.Background(), in)
		if !assert.Nil(t, err) {
			t.Errorf("Notify() error = %v", err)
			return
		}

		responseHeaders := make(http.Header)
		_ = json.Unmarshal([]byte(got.Headers), &responseHeaders)
		for s, strings := range responseHeaders {
			t.Logf("%s: %v", s, strings)
		}

		t.Logf("%s \n", got.String())
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}
